<?php

namespace Payroll\Remittance\Http\Controllers;
use Litepie\Remittance\Http\Requests\BankRemittanceRequest;
use Litepie\Remittance\Models\BankRemittance;

trait BankRemittanceWorkflow {
	
    /**
     * Workflow controller function for bank_remittance.
     *
     * @param Model   $bank_remittance
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(BankRemittanceRequest $request, BankRemittance $bank_remittance, $step)
    {

        try {

            $bank_remittance->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('remittance::bank_remittance.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/bank_remittance/bank_remittance/' . $bank_remittance->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/bank_remittance/bank_remittance/' . $bank_remittance->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for bank_remittance.
     *
     * @param Model   $bank_remittance
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(BankRemittance $bank_remittance, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $bank_remittance->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('remittance::bank_remittance.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('remittance::admin.bank_remittance.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('remittance::admin.bank_remittance.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('remittance::admin.bank_remittance.message', $data)->render();

        }

    }
}