<?php

namespace Payroll\Remittance\Providers;

use Illuminate\Support\ServiceProvider;

class RemittanceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'remittance');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'remittance');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('remittance', function ($app) {
            return $this->app->make('Payroll\Remittance\Remittance');
        });

        // Bind BankRemittance to repository
        $this->app->bind(
            'Payroll\Remittance\Interfaces\BankRemittanceRepositoryInterface',
            \Payroll\Remittance\Repositories\Eloquent\BankRemittanceRepository::class
        );

        $this->app->register(\Payroll\Remittance\Providers\AuthServiceProvider::class);
        $this->app->register(\Payroll\Remittance\Providers\EventServiceProvider::class);
        $this->app->register(\Payroll\Remittance\Providers\RouteServiceProvider::class);
        // $this->app->register(\Payroll\Remittance\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['remittance'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('payroll/remittance.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/remittance')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/remittance')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
