<?php

namespace Payroll\Remittance\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Payroll\Remittance\Models\BankRemittance;

class BankRemittanceAction
{
    /**
     * Perform the complete action.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return BankRemittance
     */
    public function complete(BankRemittance $bank_remittance)
    {
        try {
            $bank_remittance->status = 'complete';
            return $bank_remittance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return BankRemittance
     */public function verify(BankRemittance $bank_remittance)
    {
        try {
            $bank_remittance->status = 'verify';
            return $bank_remittance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return BankRemittance
     */public function approve(BankRemittance $bank_remittance)
    {
        try {
            $bank_remittance->status = 'approve';
            return $bank_remittance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return BankRemittance
     */public function publish(BankRemittance $bank_remittance)
    {
        try {
            $bank_remittance->status = 'publish';
            return $bank_remittance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return BankRemittance
     */
    public function archive(BankRemittance $bank_remittance)
    {
        try {
            $bank_remittance->status = 'archive';
            return $bank_remittance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return BankRemittance
     */
    public function unpublish(BankRemittance $bank_remittance)
    {
        try {
            $bank_remittance->status = 'unpublish';
            return $bank_remittance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
