<?php

namespace Payroll\Remittance\Workflow;

use Payroll\Remittance\Models\BankRemittance;
use Validator;

class BankRemittanceValidator
{

    /**
     * Determine if the given bank_remittance is valid for complete status.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return bool / Validator
     */
    public function complete(BankRemittance $bank_remittance)
    {
        return Validator::make($bank_remittance->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given bank_remittance is valid for verify status.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return bool / Validator
     */
    public function verify(BankRemittance $bank_remittance)
    {
        return Validator::make($bank_remittance->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given bank_remittance is valid for approve status.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return bool / Validator
     */
    public function approve(BankRemittance $bank_remittance)
    {
        return Validator::make($bank_remittance->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given bank_remittance is valid for publish status.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return bool / Validator
     */
    public function publish(BankRemittance $bank_remittance)
    {
        return Validator::make($bank_remittance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given bank_remittance is valid for archive status.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return bool / Validator
     */
    public function archive(BankRemittance $bank_remittance)
    {
        return Validator::make($bank_remittance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given bank_remittance is valid for unpublish status.
     *
     * @param BankRemittance $bank_remittance
     *
     * @return bool / Validator
     */
    public function unpublish(BankRemittance $bank_remittance)
    {
        return Validator::make($bank_remittance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
